Azure AMQP library for Rust
Azure AMQP crate for consumption of AMQP based packages in the Azure SDK for Rust and C++.
NOTE: THIS IS NOT A GENERAL PURPOSE AMQP LIBRARY AND SHOULD NOT BE USED AS SUCH.
This crate is part of a collection of crates: for more information please refer to https://github.com/azure/azure-sdk-for-rust.
Testing the AMQP Client
The AMQP package is tested using the standard cargo test command line:
cargo test --package azure_core_amqp --all-featuresCertain AMQP tests requires that there be a running AMQP broker on the machine at the time of the test (the tests will run without the broker, the relevant tests will just be skipped).
One existing AMQP broker is the “TestAMQPBroker” from the azure-amqp GitHub repository.
To launch the TestAMQPBroker, there are two ways of installing and running the TestAmqpBroker, Scripted and Manual.
Scripted Broker Install
Running the broker from a script requires that you first install Powershell. From a running powershell instance, run the powershell script in the sdk/core/azure_core_amqp directory:
./sdk/core/azure_core_amqp/Test-Setup.ps1This will download the TestAmqpBroker, build it and launch the executable in the background.
Note that this requires that you have the .NET SDK installed on your machine.
You can then run the azure_core_amqp package tests.
Once you have finished running your tests, you run:
./sdk/core/azure_core_amqp/Test-Cleanup.ps1which will terminate the test broker.
Manual Broker Install
For Manual testing, first clone the azure-amqp repository to a local directory:
cd <Test Working Directory>
git clone https://github.com/Azure/azure-amqpAlternately, you can clone to a specific release in the azure-amqp repository:
git clone https://github.com/Azure/azure-amqp.git --branch hotfixSet an environment variable the test AMQP broker should listen on:
$env:TEST_BROKER_ADDRESS = 'amqp://127.0.0.1:25672'And launch the test broker:
cd azure-amqp/test/TestAmqpBroker
dotnet run -- $env:TEST_BROKER_ADDRESSNow, when you run the cargo tests, the networking functionality of the AMQP APIs will be executed.
License: MIT
Re-exports
pub use error::*;
Modules
Structs
- Amqp
Claims Based Security - Struct representing the Claims-Based Security (CBS) functionality over AMQP.
- Amqp
Connection - Struct representing an AMQP connection.
- Amqp
Connection Options - Options for configuring an AMQP connection.
- Amqp
Delivery - An AMQP Delivery.
- Amqp
Described - An AMQP Composite type.
- Amqp
List - A sequence of AMQP values
- Amqp
Management - Struct representing the AMQP management functionality.
- Amqp
Message - An AMQP message.
- Amqp
Ordered Map - An ordered mapping from distinct keys to values.
- Amqp
Receiver - Struct representing the AMQP receiver functionality.
- Amqp
Receiver Options - Options for configuring an AMQP receiver.
- Amqp
Send Options - Options for sending an AMQP message.
- Amqp
Sender - An AMQP message sender.
- Amqp
Sender Options - AMQP Sender options.
- Amqp
Session - An AMQP Session.
- Amqp
Session Options - Options for an AMQP Session.
- Amqp
Source - An AMQP message source.
- Amqp
Symbol - An AMQP symbol.
- Amqp
Target - An AMQP link target.
- Amqp
Timestamp - AMQP Timestamp.
Enums
- Amqp
Send Outcome - Possible outcomes from a Send operation.
- Amqp
Simple Value - A simple value type in AMQP 1.0.
- Amqp
Value - An AMQP value.
- Receiver
Credit Mode - Represents the mode of issuing credit to the sender in an AMQP receiver.
- Receiver
Settle Mode - AMQP Receiver settle mode.
- Sender
Settle Mode - AMQP Sender settle mode.
Traits
- Amqp
Claims Based Security Apis - Trait defining the asynchronous APIs for Claims-Based Security (CBS) operations over AMQP.
- Amqp
Connection Apis - Trait defining the asynchronous APIs for AMQP connection operations.
- Amqp
Delivery Apis - Trait defining the APIs for interacting with an AMQP delivery.
- Amqp
Management Apis - Trait defining the asynchronous APIs for AMQP management operations.
- Amqp
Receiver Apis - Trait defining the asynchronous APIs for AMQP receiver operations.
- Amqp
Sender Apis - A trait for AMQP Sender operations.
- Amqp
Session Apis - A trait for AMQP Session operations.